==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/CustomIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { CustomIndicatorDescription } from "./CustomIndicatorDescription";
/**
 * @hidden
 */
export let CustomIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class CustomIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (CustomIndicatorDescriptionMetadata.a == null) {
                CustomIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CustomIndicatorDescriptionMetadata.c(CustomIndicatorDescriptionMetadata.a);
            }
            if (a.j(CustomIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.y(CustomIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
        }
        static d(a) {
            CustomIndicatorDescriptionMetadata.b(a);
            a.aa("CustomIndicator", () => new CustomIndicatorDescription());
            a.z("CustomIndicator", CustomIndicatorDescriptionMetadata.a);
        }
    }
    CustomIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(CustomIndicatorDescriptionMetadata, 'CustomIndicatorDescriptionMetadata');
    CustomIndicatorDescriptionMetadata.a = null;
    return CustomIndicatorDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/CustomIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { CustomIndicatorDescription } from "./CustomIndicatorDescription";
/**
 * @hidden
 */
export let CustomIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class CustomIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (CustomIndicatorDescriptionMetadata.a == null) {
                CustomIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CustomIndicatorDescriptionMetadata.c(CustomIndicatorDescriptionMetadata.a);
            }
            if (a.k(CustomIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.aa(CustomIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
        }
        static d(a) {
            CustomIndicatorDescriptionMetadata.b(a);
            a.ac("CustomIndicator", () => new CustomIndicatorDescription());
            a.ab("CustomIndicator", CustomIndicatorDescriptionMetadata.a);
        }
    }
    CustomIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(CustomIndicatorDescriptionMetadata, 'CustomIndicatorDescriptionMetadata');
    CustomIndicatorDescriptionMetadata.a = null;
    return CustomIndicatorDescriptionMetadata;
})();
